@@ -47,8 +47,10 @@ from suite_py.lib.config import Config
 from suite_py.lib.handler import git_handler as git
 from suite_py.lib.handler import prompt_utils
 from suite_py.lib.handler.captainhook_handler import CaptainHook
+from suite_py.lib.handler.git_handler import GitHandler
 from suite_py.lib.handler.okta_handler import Okta
 from suite_py.lib.handler.pre_commit_handler import PreCommit
+from suite_py.lib.handler.youtrack_handler import YoutrackHandler
 from suite_py.lib.tokens import Tokens
 
 # pylint: enable=wrong-import-position
@@ -176,17 +178,21 @@ def main(ctx, project, timeout, verbose):
     if timeout:
         config.user["captainhook_timeout"] = timeout
 
-    project = os.path.basename(project)
     tokens = Tokens()
     okta = Okta(config, tokens)
     captainhook = CaptainHook(config, okta, tokens)
+    project = os.path.basename(project)
+    git_handler = GitHandler(project, config)
+    youtrack_handler = YoutrackHandler(config, tokens)
 
     ctx.obj = Context(
+        captainhook=captainhook,
+        config=config,
+        git_handler=git_handler,
+        okta=okta,
         project=project,
         tokens=tokens,
-        okta=okta,
-        config=config,
-        captainhook=captainhook,
+        youtrack_handler=youtrack_handler,
     )
 
     ctx.obj.call(metrics.setup)
@@ -233,12 +239,27 @@ def bump(obj: Context, project: Optional[str] = None, version: Optional[str] = N
     is_flag=True,
     help="Stash uncommitted changes before creating the branch and reapply them afterward",
 )
+@click.option(
+    "--parent-branch",
+    type=click.STRING,
+    help="Parent branch to create the new branch from",
+)
+@click.option(
+    "--branch-name",
+    type=click.STRING,
+    help="Branch name template. Supports {card_id}, {type}, {summary} placeholders (ex. '{card_id}/{type}/{summary}')",
+)
 @click.pass_obj
 @catch_exceptions
-def cli_create_branch(obj, card, autostash):
+def cli_create_branch(obj, card, autostash, parent_branch, branch_name):
     from suite_py.commands.create_branch import CreateBranch
 
-    obj.call(CreateBranch, card=card, autostash=autostash).run()
+    obj.call(CreateBranch).run(
+        card_id=card,
+        autostash=autostash,
+        parent_branch=parent_branch,
+        branch_name=branch_name,
+    )
 
 
 @main.command("lock", help="Lock project on staging or prod")
@@ -326,12 +347,34 @@ def release():
 @release.command(
     "create", help="Create a github release (and deploy it if GHA are used)"
 )
+@click.argument(
+    "commit",
+    required=False,
+    type=str,
+    metavar="[COMMIT]",
+)
+@click.option(
+    "--interactive",
+    "-i",
+    is_flag=True,
+    help="Interactively choose which unreleased commit to release (ignored if COMMIT is provided)",
+)
 @click.pass_obj
 @catch_exceptions
-def cli_release_create(obj):
+def cli_release_create(obj, commit, interactive):  # type: ignore[override]
+    """Create a release.
+
+    Optionally pass a COMMIT (full or short SHA) to create the release at that
+    specific commit instead of the latest commit (HEAD). Example:
+
+        suite-py release create 644a699
+
+    If you don't provide a COMMIT you can pass --interactive / -i to select
+    one among the unreleased commits (those after the last tag).
+    """
     from suite_py.commands.release import Release
 
-    obj.call(Release, action="create").run()
+    obj.call(Release, action="create", commit=commit, interactive=interactive).run()
 
 
 @main.command("status", help="Current status of a project")
