@@ -1,16 +1,15 @@
 # -*- coding: utf-8 -*-
 from halo import Halo
 
-from suite_py.lib import logger
-from suite_py.lib import metrics
+from suite_py.lib import logger, metrics
 from suite_py.lib.handler.captainhook_handler import CaptainHook
 from suite_py.lib.symbol import CHECKMARK, CROSSMARK
 
 
 class Status:
-    def __init__(self, project, config):
+    def __init__(self, project, captainhook: CaptainHook):
         self._project = project
-        self._captainhook = CaptainHook(config)
+        self._captainhook = captainhook
 
     @metrics.command("status")
     def run(self):
