@@ -70,13 +70,10 @@ def ask_multiple_choices(question_text, choices):
     return answer["values"]
 
 
-def checkbox_with_manual_fallback(
-    checkbox_msg, fallback_msg, choices, autocomplete=None
-):
-
+def checkbox_with_manual_fallback(msg, choices, autocomplete=None):
     question = inquirer.Checkbox(
         "value",
-        checkbox_msg,
+        msg,
         choices,
         other=True,
         autocomplete=autocomplete,
@@ -85,16 +82,17 @@ def checkbox_with_manual_fallback(
     if not answer:
         question = inquirer.Text(
             "value",
-            fallback_msg,
+            msg,
             autocomplete=autocomplete,
         )
         answer = [inquirer.prompt([question])["value"]]
+
     return answer
 
 
 def make_completer(comprehension):
     """
-    Builds am inquirer completer for the given list generator. The generator
+    Builds an inquirer completer for the given list generator. The generator
     should consume a string and return a list of strings for auto-complete suggestion
     """
 
