@@ -1,5 +1,5 @@
 import dataclasses
-from typing import Dict, List, Optional, Literal
+from typing import Dict, List, Literal, Optional
 
 import semver
 from halo import Halo
